@@ -3,6 +3,7 @@ from responsive_admin.conf import settings
 
 register = template.Library()
 
+
 def max_width():
     if settings.RESPONSIVE_ADMIN_CONTAINER_MAX_WIDTH != 0:
         style = '%ipx' % settings.RESPONSIVE_ADMIN_CONTAINER_MAX_WIDTH
@@ -10,4 +11,11 @@ def max_width():
     else:
         return 'none'
 
-register.simple_tag(max_width)
\ No newline at end of file
+
+@register.inclusion_tag('templatetags/fixed_submit_line.html')
+def fixed_submit_line():
+    return {'FIXED_SUBMIT_LINE': settings.RESPONSIVE_ADMIN_FIXED_SUBMIT_LINE}
+
+
+register.simple_tag(max_width)
+
